BaseIterator<T> class abstract

Constructors

BaseIterator()

Properties

done ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

characteristics() → int
estimateSize() → int
forEachRemaining(JConsumer<T> action) → dynamic
getExactSizeIfKnown() → int
next() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DISTINCT → const int
IMMUTABLE → const int
ORDERED → const int
SIZED → const int
SORTED → const int